from distutils.core import setup
setup(
  name = 'shirtctl',         
  packages = ['shirtctl'],   
  version = '0.0',      
  license='MIT',        
  description = 'The shirtctl Python SDK', 
  author = 'Blair Hudson',                
  author_email = 'blair@shirtctl.com',     
  url = 'https://github.com/shirtctl/shirtctl-python-sdk',   
  # download_url = '',    
  keywords = ['shirtctl', 'Python', 'SDK'],   
  install_requires=[],
  classifiers=[]
)